@@ -263,8 +263,8 @@ setGeneric(
 #'
 #' @param x A [`data.frame`].
 #' @param column A (named) `vector`.
-#' @param after A length-one [`numeric`] vector specifying a subscript,
-#'  after which the new column is to be appended.
+#' @param after An [`integer`] specifying a subscript, after which the new
+#'  column is to be appended.
 #' @param var A [`character`] string giving the name of the new column.
 #' @param ... Currently not used.
 #' @details
@@ -604,7 +604,7 @@ setGeneric(
 
 #' Confidence Interval for Binomial Proportions
 #'
-#' Computes a Wald interval for a proportion at a desired level of significance.
+#' Computes Wald interval for a proportion at a desired level of significance.
 #' @param object A [`numeric`] vector giving the number of success.
 #' @param n A length-one [`numeric`] vector giving the number of trials.
 #' @param level A length-one [`numeric`] vector giving the confidence level.
@@ -628,7 +628,7 @@ setGeneric(
 
 #' Confidence Interval for Multinomial Proportions
 #'
-#' Computes a Wald interval for a proportion at a desired level of significance.
+#' Computes Wald interval for a proportion at a desired level of significance.
 #' @param object A [`numeric`] vector of positive integers giving the number of
 #'  occurrences of each class.
 #' @param level A length-one [`numeric`] vector giving the confidence level.
@@ -650,9 +650,91 @@ setGeneric(
   def = function(object, ...) standardGeneric("confidence_multinomial")
 )
 
+#' Nonparametric Bootstrap Confidence Interval
+#'
+#' Computes equi-tailed two-sided nonparametric confidence interval.
+#' @param object A [`numeric`] vector giving the bootstrap replicates of the
+#'  statistic of interest.
+#' @param level A length-one [`numeric`] vector giving the confidence level.
+#'  Must be a single number between \eqn{0} and \eqn{1}.
+#' @param type A [`character`] string giving the type of confidence
+#'  interval to be returned. It must be one "`basic`" (the default),
+#'  "`student`", "`normal`" or "`percentiles`". Any unambiguous substring can be
+#'  given.
+#' @param t0 A length-one [`numeric`] vector giving the observed value of the
+#'  statistic of interest. Must be defined if `type` is "`basic`", "`student`"
+#'  or "`normal`".
+#' @param var_t0 A length-one [`numeric`] vector giving an estimate of the
+#'  variance of the statistic of interest. Must be defined if `type` is
+#'  "`student`". If `var_t0` is undefined and `type` is "`normal`, it defaults
+#'  to `var(object)`.
+#' @param var_t A [`numeric`] vector giving the variances of the bootstrap
+#'  replicates of the variable of interest. Must be defined if `type` is
+#' "`student`".
+#' @param ... Currently not used.
+#' @return A length-two [`numeric`] vector giving the lower and upper confidence
+#'  limits.
+#' @references
+#'  Davison, A. C. & Hinkley, D. V. (1997). *Bootstrap Methods and Their
+#'  Application*. Cambridge Series on Statistical and Probabilistic Mathematics.
+#'  Cambridge: Cambridge University Press.
+#' @seealso [bootstrap()]
+#' @example inst/examples/ex-bootstrap.R
+#' @author N. Frerebeau
+#' @docType methods
+#' @family summary statistics
+#' @aliases confidence_bootstrap-method
+setGeneric(
+  name = "confidence_bootstrap",
+  def = function(object, ...) standardGeneric("confidence_bootstrap")
+)
+
 # Resampling ===================================================================
+#' Draw Uniform Random Sample
+#'
+#' Draws a random (sub)sample (with or without replacement).
+#' @param object A [`numeric`] vector.
+#' @param n A non-negative [`integer`] specifying the number of random vector
+#'  to draw.
+#' @param size A non-negative [`integer`] specifying the sample size.
+#' @param replace A [`logical`] scalar: should sampling be with replacement?
+#' @param ... Currently not used.
+#' @return
+#'  A `numeric` [`matrix`] with `n` rows and `size` columns.
+#' @example inst/examples/ex-resample.R
+#' @author N. Frerebeau
+#' @docType methods
+#' @family resampling methods
+#' @aliases resample_uniform-method
+setGeneric(
+  name = "resample_uniform",
+  def = function(object, ...) standardGeneric("resample_uniform")
+)
+
+#' Draw Multinomial Random Sample
+#'
+#' Draws a random (sub)sample from a multinomial distribution.
+#' @param object A length-\eqn{k} [`integer`] vector, specifying the probability
+#'  for the \eqn{k} classes; is internally normalized to sum to 1.
+#' @param n A non-negative [`integer`] specifying the number of random vector
+#'  to draw.
+#' @param size A non-negative [`integer`] specifying the sample size.
+#' @param ... Currently not used.
+#' @return
+#'  A `numeric` [`matrix`] with `n` rows and `k` columns.
+#' @seealso [stats::rmultinom()]
+#' @example inst/examples/ex-resample.R
+#' @author N. Frerebeau
+#' @docType methods
+#' @family resampling methods
+#' @aliases resample_multinomial-method
+setGeneric(
+  name = "resample_multinomial",
+  def = function(object, ...) standardGeneric("resample_multinomial")
+)
+
 ## Bootstrap -------------------------------------------------------------------
-#' Bootstrap Estimation
+#' Nonparametric Bootstrap Estimation
 #'
 #' Samples randomly from the elements of `object` with replacement.
 #' @param object A [`numeric`] vector.
@@ -662,6 +744,13 @@ setGeneric(
 #'  replications.
 #' @param f A [`function`] that takes a single numeric vector (the result of
 #'  `do`) as argument.
+#' @param level A length-one [`numeric`] vector giving the confidence level.
+#'  Must be a single number between \eqn{0} and \eqn{1}. Only used if `f` is
+#'  `NULL`.
+#' @param interval A [`character`] string giving the type of confidence
+#'  interval to be returned. It must be one "`basic`" (the default), "`normal`"
+#'  or "`percentiles`" (see [confidence_bootstrap()]). Any unambiguous substring
+#'  can be given. Only used if `f` is `NULL`.
 #' @param ... Extra arguments to be passed to `do`.
 #' @return
 #'  If `f` is `NULL` (the default), `bootstrap()` returns a named `numeric`
@@ -670,16 +759,22 @@ setGeneric(
 #'   \item{`original`}{The observed value of `do` applied to `object`.}
 #'   \item{`mean`}{The bootstrap estimate of mean of `do`.}
 #'   \item{`bias`}{The bootstrap estimate of bias of `do`.}
-#'   \item{`error`}{he bootstrap estimate of standard error of `do`.}
+#'   \item{`error`}{The bootstrap estimate of standard error of `do`.}
+#'   \item{`lower`}{The lower limit of the bootstrap confidence interval at `level`.}
+#'   \item{`upper`}{The upper limit of the bootstrap confidence interval at `level`}
 #'  }
 #'
 #'  If `f` is a `function`, `bootstrap()` returns the result of `f` applied to
 #'  the `n` values of `do`.
-#' @example inst/examples/ex-resample.R
+#' @references
+#'  Davison, A. C. & Hinkley, D. V. (1997). *Bootstrap Methods and Their
+#'  Application*. Cambridge Series on Statistical and Probabilistic Mathematics.
+#'  Cambridge: Cambridge University Press.
+#' @seealso [confidence_bootstrap()]
+#' @example inst/examples/ex-bootstrap.R
 #' @author N. Frerebeau
 #' @docType methods
 #' @family resampling methods
-#' @rdname bootstrap
 #' @aliases bootstrap-method
 setGeneric(
   name = "bootstrap",
@@ -702,16 +797,15 @@ setGeneric(
 #'   \item{`original`}{The observed value of `do` applied to `object`.}
 #'   \item{`mean`}{The jackknife estimate of mean of `do`.}
 #'   \item{`bias`}{The jackknife estimate of bias of `do`.}
-#'   \item{`error`}{he jackknife estimate of standard error of `do`.}
+#'   \item{`error`}{The jackknife estimate of standard error of `do`.}
 #'  }
 #'
 #'  If `f` is a `function`, `jackknife()` returns the result of `f` applied to
 #'  the leave-one-out values of `do`.
-#' @example inst/examples/ex-resample.R
+#' @example inst/examples/ex-jackknife.R
 #' @author N. Frerebeau
 #' @docType methods
 #' @family resampling methods
-#' @rdname jackknife
 #' @aliases jackknife-method
 setGeneric(
   name = "jackknife",
